@@ -6,32 +6,28 @@ Class, Function
 ===============
 """
 
-__copyright__ = 'Copyright (C) 2021 @koKkekoh'
-__license__ = 'BSD 2-Clause License'
-__author__  = '@koKekkoh'
-__version__ = '0.29.2' # 2021-11-17
-__url__     = 'https://qiita.com/tags/sphinxcotrib.kana_text'
-
 import re, pathlib
 from typing import TYPE_CHECKING, Any, Dict, List, Tuple, Pattern, Type, cast
 
 from docutils import nodes
-from docutils.nodes import Node, Text, Element, system_message
 
-from sphinx import addnodes
-import sphinx.builders.html as builders
-from sphinx.config import Config
-from sphinx.domains.index import IndexDomain, IndexRole
+from sphinx.domains.index import IndexRole
 from sphinx.errors import NoUri
-from sphinx.environment.adapters.indexentries import IndexEntries
 from sphinx.locale import _, __
 from sphinx.util import logging, split_into, docutils
-from sphinx.util.nodes import process_index_entry
 from sphinx.writers import html5
 
 import sphindexer as idxr
 from sphindexer.rack import UNIT_CLSF, UNIT_TERM, UNIT_SBTM
 
+
+__copyright__ = 'Copyright (C) 2021 @koKkekoh'
+__license__ = 'BSD 2-Clause License'
+__author__  = '@koKekkoh'
+__version__ = '0.30.0' # 2021-11-23
+__url__     = 'https://qiita.com/tags/sphinxcotrib.kana_text'
+
+
 logger = logging.getLogger(__name__)
 
 
@@ -70,18 +66,19 @@ def parser_for_kana_text(separator, option_marker):
 
     return re.compile(ahead + re_kana + re_word + re_mark)
 
-#オプションに「a-z」があるか
+#オプションに英字があるか
 _a2z = re.compile(r'[a-zA-Z]')
 
-#「かな|単語^オプション」のオプションの変換用
-_s2i_each_together = {
-    'a': 1, 'b': 2, 'c': 3, 'd': 4, 'e': 5,
-    'f': 6, 'g': 7, 'h': 8, 'i': 9
+#「かな|単語^オプション」の「オプション」の変換用
+class _s2i:
+    each_together = {
+        'a': 1, 'b': 2, 'c': 3, 'd': 4, 'e': 5,
+        'f': 6, 'g': 7, 'h': 8, 'i': 9
     }
 
-_s2i_step_by_step = {
-    'q': 1, 'r': 2, 's': 3, 't': 4, 'u': 5,
-    'v': 6, 'w': 7, 'x': 8, 'y': 9
+    step_by_step = {
+        'q': 1, 'r': 2, 's': 3, 't': 4, 'u': 5,
+        'v': 6, 'w': 7, 'x': 8, 'y': 9
     }
 
 def make_html_with_ruby(word: str, kana: str) -> str:
@@ -115,13 +112,13 @@ def make_specific_by_parsing_option(word, kana, option):
     for o in opt:
         if not word[t_s:] or not kana[r_s:]: #文字がない
             break
-        elif o in _s2i_each_together: #ルビとしては使用しない
-            t_end = t_s + _s2i_each_together[o]
-            r_end = r_s + _s2i_each_together[o]
+        elif o in _s2i.each_together: #ルビとしては使用しない
+            t_end = t_s + _s2i.each_together[o]
+            r_end = r_s + _s2i.each_together[o]
             rtn.append((False,word[t_s:t_end]))
-        elif o in _s2i_step_by_step: #ルビとしては使用しない
+        elif o in _s2i.step_by_step: #ルビとしては使用しない
             t_end = t_s + 1
-            r_end = r_s + _s2i_step_by_step[o]
+            r_end = r_s + _s2i.step_by_step[o]
             rtn.append((False,word[t_s:t_end]))
         elif _a2z.match(o): #上記以外の文字は無視する
             continue
@@ -145,15 +142,15 @@ def make_specific_by_parsing_option(word, kana, option):
 class KanaText(nodes.Element):
     """かな文字を扱うTextクラス
 
-    - Jinja2のstring判定ではFalseとなるように、reprunicode(str)は継承しない.
-    - __str__はText.astext()と同じ挙動としてasideo()を使う.
-    - KanaText.astext()は簡易IDとして扱う.
+    - 内部表現としては「よみ|記載文字」をIDとして、他の情報は属性値として扱う.
+    - 表示に於いては「記載文字」が同じであれば、同じ「読み」として処理する.
+    - self.astext()を「表示すべき標準的な記載文字」を返すメソッドとする.
     """
 
     children = () #これでTextクラスと同じ扱いになる.
     config = None
 
-    def __init__(self, rawword, rawtext=''):
+    def __init__(self, rawword, rawsource=''):
         """
         doctest:
 
@@ -161,7 +158,6 @@ class KanaText(nodes.Element):
             >>> kana
             <KanaText: len=2 ruby='specific' option='b1' <#text: 'はなこ|はな子'>>
         """
-
         if self.config and _dflt_separator != self.config.kana_text_separator:
             separator = self.config.kana_text_separator
         else:
@@ -173,14 +169,11 @@ class KanaText(nodes.Element):
             option_marker = _dflt_option_marker
 
         self._rawword = rawword
-        self._rawtext = rawtext
         self._separator = separator
         self._option_marker = option_marker
         self.whatiam = 'term' #in('classifier', 'term')
 
-        if rawtext:
-            rawsource = rawtext
-        else:
+        if not rawsource:
             rawsource = rawword
 
         delimiter = _chop.sub('', separator)
@@ -205,37 +198,41 @@ class KanaText(nodes.Element):
 
     def __str__(self):
         """jinja2用"""
-        if self.whatiam == 'term' and self.kana_text_on_genindex:
+        try:
+            # IndexRackで初めて設定されるので、タイミングによっては存在しない.
+            parameter = self.kana_text_on_genindex
+        except AttributeError:
+            return self.astext()
+
+        if self.whatiam == 'term' and parameter:
             return self.ashtml()
         else:
             return self.astext()
 
     def __repr__(self):
-        return self.entity_of_repr()
-
-    def entity_of_repr(self):
         """
         doctest:
             >>> kana = KanaText('はなこ|はな子^b1')
             >>> kana
             <KanaText: len=2 ruby='specific' option='b1' <#text: 'はなこ|はな子'>>
         """
-        name = self.__class__.__name__
-        rb, op = self['ruby'], self['option']
-        ideo, kana = self['ideo'], self['kana']
-        if kana:
-            prop = f"<{name}: len={len(self)} "
-            if len(rb) > 0: prop += f"ruby='{rb}' "
-            if len(op) > 0: prop += f"option='{op}' "
-            prop += f"<#text: '{kana}|{ideo}'>>"
+        return self.asrepr()
 
+    def asrepr(self):
+        name = self.__class__.__name__
+        if self['ideo']:
+            prop = f"<{name}: len={len(self)} "
+            if self['kana']:
+                if len(self['ruby']) > 0:
+                    prop += f"ruby='{self['ruby']}' "
+                if len(self['option']) > 0:
+                    prop += f"option='{self['option']}' "
+                prop += f"<#text: '{self['kana']}|{self['ideo']}'>>"
+            else:
+                prop += f"<#text: '{self['ideo']}'>>"
             return prop
-        elif ideo:
-            return f"<{name}: len={len(self)} <#text: '{ideo}'>>"
-        elif self._rawword:
-            return f"<{name}: <#rawword: '{self._rawword}'>>"
-        elif self._rawtext:
-            return f"<#rawtext: '{self._rawtext}'>"
+        elif self.rawsource:
+            return f"<#rawsource: '{self.rawsource}'>"
         else:
             return "<#text: ''>"
 
@@ -243,9 +240,9 @@ class KanaText(nodes.Element):
         """
         doctest:
 
-            >>> kana = KanaText('たなかひさみつ|田中ひさみつ^12d')
+            >>> kana = KanaText('たなかはなこ|田中はな子^12b1')
             >>> kana
-            <KanaText: len=2 ruby='specific' option='12d' <#text: 'たなかひさみつ|田中ひさみつ'>>
+            <KanaText: len=2 ruby='specific' option='12b1' <#text: 'たなかはなこ|田中はな子'>>
         """
         match = parser.match(text)
 
@@ -265,7 +262,8 @@ class KanaText(nodes.Element):
         return ideo, kana, ruby, opt
 
     def astext(self):
-        return self._as_standard()
+        if self['ideo']: return self['ideo']
+        return ''
 
     def assort(self):
         if self.whatiam != 'classifier':
@@ -279,10 +277,6 @@ class KanaText(nodes.Element):
         else:
             return (1, key)
 
-    def _as_standard(self):
-        if self['ideo']: return self['ideo']
-        return ''
-
     def as_identifier(self):
         if self['kana']: return self['kana'] + self['delimiter'] + self['ideo']
         if self['ideo']: return self['ideo']
@@ -301,16 +295,6 @@ class KanaText(nodes.Element):
             return ''
         # len(self) < 1の時は、__len__内でValueErrorが発生する
 
-    def asideo(self):
-        """
-        doctest:
-            >>> kana = KanaText('たなかはなこ|田中はな子^12b1')
-            >>> kana.asideo()
-            '田中はな子'
-        """
-        if len(self) > 0:
-            return self['ideo']
-
     def asruby(self):
         """
         doctest:
@@ -421,71 +405,124 @@ class ExtIndexEntry(idxr.IndexEntry):
     packclass = ExtSubterm
     unitclass = ExtIndexUnit
 
+    testmode = False
+
+    def make_index_units(self):
+        """
+        sphinx/util/nodes.py
+        
+        - process_index_entryが参照するindextypesをしないと機能しないメソッド.
+        - いずれどうにかしたいので、コードは残しておく.
+        """
+
+        if self['entry_type'] not in ('keys', 'pairs'):
+            return super().make_index_units()
+
+        if not self.testmode:
+            message = 'see: process_index_entry and indextypes in sphinx/util/nodes.py'
+            raise NotImplementedError(message)
+
+        fn = self['file_name']
+        tid = self['target']
+        main = self['main']
+        index_key = self['index_key']
+
+        def _index_unit(term, sub1, sub2):
+            link = self.type2link('uri')
+            emphasis = self.main2code(main)
+
+            if not sub1:
+                sub1 = self.textclass('')
+            if not sub2:
+                sub2 = self.textclass('')
+            subterm = self.packclass(link, sub1, sub2)
+
+            index_unit = self.unitclass(term, subterm, link, emphasis, fn, tid, index_key)
+            return index_unit
+
+        index_units = []
+        try:
+            last = len(self) - 1
+            for i in range(last):
+                if self['entry_type'] == 'pairs':
+                    index_units.append(_index_unit(self[last], self[i], ''))
+                index_units.append(_index_unit(self[i], self[last], ''))
+        except IndexError as err:
+            raise IndexError(str(err), repr(self))
+        except ValueError as err:
+            logger.warning(str(err), location=fn)
+
+        print(index_units)
+        return index_units
+
 
 # ------------------------------------------------------------
 
 
-_first_char_small = {
-    'あ': 'あ', 'い': 'あ', 'う': 'あ', 'え': 'あ', 'お': 'あ',
-    'ア': 'あ', 'イ': 'あ', 'ウ': 'あ', 'エ': 'あ', 'オ': 'あ',
-    'か': 'か', 'き': 'か', 'く': 'か', 'け': 'か', 'こ': 'か',
-    'カ': 'か', 'キ': 'か', 'ク': 'か', 'ケ': 'か', 'コ': 'か',
-    'が': 'か', 'ぎ': 'か', 'ぐ': 'か', 'げ': 'か', 'ご': 'か',
-    'ガ': 'か', 'ギ': 'か', 'グ': 'か', 'ゲ': 'か', 'ゴ': 'か',
-    'さ': 'さ', 'し': 'さ', 'す': 'さ', 'せ': 'さ', 'そ': 'さ',
-    'サ': 'さ', 'シ': 'さ', 'ス': 'さ', 'セ': 'さ', 'ソ': 'さ',
-    'ざ': 'さ', 'じ': 'さ', 'ず': 'さ', 'ぜ': 'さ', 'ぞ': 'さ',
-    'ザ': 'さ', 'ジ': 'さ', 'ズ': 'さ', 'ゼ': 'さ', 'ゾ': 'さ',
-    'た': 'た', 'ち': 'た', 'つ': 'た', 'て': 'た', 'と': 'た',
-    'タ': 'た', 'チ': 'た', 'ツ': 'た', 'テ': 'た', 'ト': 'た',
-    'だ': 'た', 'ぢ': 'た', 'づ': 'た', 'で': 'た', 'ど': 'た',
-    'ダ': 'た', 'ヂ': 'た', 'ヅ': 'た', 'デ': 'た', 'ド': 'た',
-    'な': 'な', 'に': 'な', 'ぬ': 'な', 'ね': 'な', 'の': 'な',
-    'ナ': 'な', 'ニ': 'な', 'ヌ': 'な', 'ネ': 'な', 'ノ': 'な',
-    'は': 'は', 'ひ': 'は', 'ふ': 'は', 'へ': 'は', 'ほ': 'は',
-    'ハ': 'は', 'ヒ': 'は', 'フ': 'は', 'ヘ': 'は', 'ホ': 'は',
-    'ば': 'は', 'び': 'は', 'ぶ': 'は', 'べ': 'は', 'ぼ': 'は',
-    'バ': 'は', 'ビ': 'は', 'ブ': 'は', 'ベ': 'は', 'ボ': 'は',
-    'ぱ': 'は', 'ぴ': 'は', 'ぷ': 'は', 'ぺ': 'は', 'ぽ': 'は',
-    'パ': 'は', 'ピ': 'は', 'プ': 'は', 'ペ': 'は', 'ポ': 'は',
-    'ま': 'ま', 'み': 'ま', 'む': 'ま', 'め': 'ま', 'も': 'ま',
-    'マ': 'ま', 'ミ': 'ま', 'ム': 'ま', 'メ': 'ま', 'モ': 'ま',
-    'や': 'や', 'ゆ': 'や', 'よ': 'や', 'ヤ': 'や', 'ユ': 'や', 'ヨ': 'や',
-    'ゃ': 'や', 'ゅ': 'や', 'ょ': 'や', 'ャ': 'や', 'ュ': 'や', 'ョ': 'や',
-    'ら': 'ら', 'り': 'ら', 'る': 'ら', 'れ': 'ら', 'ろ': 'ら',
-    'ラ': 'ら', 'リ': 'ら', 'ル': 'ら', 'レ': 'ら', 'ロ': 'ら',
-    'わ': 'わ', 'を': 'わ', 'ワ': 'わ', 'ヲ': 'わ', 'ん': 'わ', 'ン': 'わ'}
+class _first_char(object):
+    small = {
+        'あ': 'あ', 'い': 'あ', 'う': 'あ', 'え': 'あ', 'お': 'あ',
+        'ア': 'あ', 'イ': 'あ', 'ウ': 'あ', 'エ': 'あ', 'オ': 'あ',
+        'か': 'か', 'き': 'か', 'く': 'か', 'け': 'か', 'こ': 'か',
+        'カ': 'か', 'キ': 'か', 'ク': 'か', 'ケ': 'か', 'コ': 'か',
+        'が': 'か', 'ぎ': 'か', 'ぐ': 'か', 'げ': 'か', 'ご': 'か',
+        'ガ': 'か', 'ギ': 'か', 'グ': 'か', 'ゲ': 'か', 'ゴ': 'か',
+        'さ': 'さ', 'し': 'さ', 'す': 'さ', 'せ': 'さ', 'そ': 'さ',
+        'サ': 'さ', 'シ': 'さ', 'ス': 'さ', 'セ': 'さ', 'ソ': 'さ',
+        'ざ': 'さ', 'じ': 'さ', 'ず': 'さ', 'ぜ': 'さ', 'ぞ': 'さ',
+        'ザ': 'さ', 'ジ': 'さ', 'ズ': 'さ', 'ゼ': 'さ', 'ゾ': 'さ',
+        'た': 'た', 'ち': 'た', 'つ': 'た', 'て': 'た', 'と': 'た',
+        'タ': 'た', 'チ': 'た', 'ツ': 'た', 'テ': 'た', 'ト': 'た',
+        'だ': 'た', 'ぢ': 'た', 'づ': 'た', 'で': 'た', 'ど': 'た',
+        'ダ': 'た', 'ヂ': 'た', 'ヅ': 'た', 'デ': 'た', 'ド': 'た',
+        'な': 'な', 'に': 'な', 'ぬ': 'な', 'ね': 'な', 'の': 'な',
+        'ナ': 'な', 'ニ': 'な', 'ヌ': 'な', 'ネ': 'な', 'ノ': 'な',
+        'は': 'は', 'ひ': 'は', 'ふ': 'は', 'へ': 'は', 'ほ': 'は',
+        'ハ': 'は', 'ヒ': 'は', 'フ': 'は', 'ヘ': 'は', 'ホ': 'は',
+        'ば': 'は', 'び': 'は', 'ぶ': 'は', 'べ': 'は', 'ぼ': 'は',
+        'バ': 'は', 'ビ': 'は', 'ブ': 'は', 'ベ': 'は', 'ボ': 'は',
+        'ぱ': 'は', 'ぴ': 'は', 'ぷ': 'は', 'ぺ': 'は', 'ぽ': 'は',
+        'パ': 'は', 'ピ': 'は', 'プ': 'は', 'ペ': 'は', 'ポ': 'は',
+        'ま': 'ま', 'み': 'ま', 'む': 'ま', 'め': 'ま', 'も': 'ま',
+        'マ': 'ま', 'ミ': 'ま', 'ム': 'ま', 'メ': 'ま', 'モ': 'ま',
+        'や': 'や', 'ゆ': 'や', 'よ': 'や', 'ヤ': 'や', 'ユ': 'や', 'ヨ': 'や',
+        'ゃ': 'や', 'ゅ': 'や', 'ょ': 'や', 'ャ': 'や', 'ュ': 'や', 'ョ': 'や',
+        'ら': 'ら', 'り': 'ら', 'る': 'ら', 'れ': 'ら', 'ろ': 'ら',
+        'ラ': 'ら', 'リ': 'ら', 'ル': 'ら', 'レ': 'ら', 'ロ': 'ら',
+        'わ': 'わ', 'を': 'わ', 'ワ': 'わ', 'ヲ': 'わ', 'ん': 'わ', 'ン': 'わ'
+        }
 
-_first_char_large = {
-    'あ': 'あ', 'い': 'い', 'う': 'う', 'え': 'え', 'お': 'お',
-    'ア': 'あ', 'イ': 'い', 'ウ': 'う', 'エ': 'え', 'オ': 'お',
-    'か': 'か', 'き': 'き', 'く': 'く', 'け': 'け', 'こ': 'こ',
-    'カ': 'か', 'キ': 'き', 'ク': 'く', 'ケ': 'け', 'コ': 'こ',
-    'が': 'か', 'ぎ': 'き', 'ぐ': 'く', 'げ': 'け', 'ご': 'こ',
-    'さ': 'さ', 'し': 'し', 'す': 'す', 'せ': 'せ', 'そ': 'そ',
-    'ガ': 'か', 'ギ': 'き', 'グ': 'く', 'ゲ': 'け', 'ゴ': 'こ',
-    'サ': 'さ', 'シ': 'し', 'ス': 'す', 'セ': 'せ', 'ソ': 'そ',
-    'ざ': 'さ', 'じ': 'し', 'ず': 'す', 'ぜ': 'せ', 'ぞ': 'そ',
-    'ザ': 'さ', 'ジ': 'し', 'ズ': 'す', 'ゼ': 'せ', 'ゾ': 'そ',
-    'た': 'た', 'ち': 'ち', 'つ': 'つ', 'て': 'て', 'と': 'と',
-    'タ': 'た', 'チ': 'ち', 'ツ': 'つ', 'テ': 'て', 'ト': 'と',
-    'だ': 'た', 'ぢ': 'ち', 'づ': 'つ', 'で': 'て', 'ど': 'と',
-    'ダ': 'た', 'ヂ': 'ち', 'ヅ': 'つ', 'デ': 'て', 'ド': 'と',
-    'な': 'な', 'に': 'に', 'ぬ': 'ぬ', 'ね': 'ね', 'の': 'の',
-    'ナ': 'な', 'ニ': 'に', 'ヌ': 'ぬ', 'ネ': 'ね', 'ノ': 'の',
-    'は': 'は', 'ひ': 'ひ', 'ふ': 'ふ', 'へ': 'へ', 'ほ': 'ほ',
-    'ハ': 'は', 'ヒ': 'ひ', 'フ': 'ふ', 'ヘ': 'へ', 'ホ': 'ほ',
-    'ば': 'は', 'び': 'ひ', 'ぶ': 'ふ', 'べ': 'へ', 'ぼ': 'ほ',
-    'バ': 'は', 'ビ': 'ひ', 'ブ': 'ふ', 'ベ': 'へ', 'ボ': 'ほ',
-    'ま': 'ま', 'み': 'み', 'む': 'む', 'め': 'め', 'も': 'も',
-    'ぱ': 'は', 'ぴ': 'ひ', 'ぷ': 'ふ', 'ぺ': 'へ', 'ぽ': 'ほ',
-    'パ': 'は', 'ピ': 'ひ', 'プ': 'ふ', 'ペ': 'へ', 'ポ': 'ほ',
-    'マ': 'ま', 'ミ': 'み', 'ム': 'む', 'メ': 'め', 'モ': 'も',
-    'や': 'や', 'ゆ': 'ゆ', 'よ': 'よ', 'ヤ': 'や', 'ユ': 'ゆ', 'ヨ': 'よ',
-    'ゃ': 'や', 'ゅ': 'ゆ', 'ょ': 'よ', 'ャ': 'や', 'ュ': 'ゆ', 'ョ': 'よ',
-    'ら': 'ら', 'り': 'り', 'る': 'る', 'れ': 'れ', 'ろ': 'ろ',
-    'ラ': 'ら', 'リ': 'り', 'ル': 'る', 'レ': 'れ', 'ロ': 'ろ',
-    'わ': 'わ', 'を': 'を', 'ん': 'ん', 'ワ': 'わ', 'ヲ': 'を', 'ン': 'ん'}
+    large = {
+        'あ': 'あ', 'い': 'い', 'う': 'う', 'え': 'え', 'お': 'お',
+        'ア': 'あ', 'イ': 'い', 'ウ': 'う', 'エ': 'え', 'オ': 'お',
+        'か': 'か', 'き': 'き', 'く': 'く', 'け': 'け', 'こ': 'こ',
+        'カ': 'か', 'キ': 'き', 'ク': 'く', 'ケ': 'け', 'コ': 'こ',
+        'が': 'か', 'ぎ': 'き', 'ぐ': 'く', 'げ': 'け', 'ご': 'こ',
+        'さ': 'さ', 'し': 'し', 'す': 'す', 'せ': 'せ', 'そ': 'そ',
+        'ガ': 'か', 'ギ': 'き', 'グ': 'く', 'ゲ': 'け', 'ゴ': 'こ',
+        'サ': 'さ', 'シ': 'し', 'ス': 'す', 'セ': 'せ', 'ソ': 'そ',
+        'ざ': 'さ', 'じ': 'し', 'ず': 'す', 'ぜ': 'せ', 'ぞ': 'そ',
+        'ザ': 'さ', 'ジ': 'し', 'ズ': 'す', 'ゼ': 'せ', 'ゾ': 'そ',
+        'た': 'た', 'ち': 'ち', 'つ': 'つ', 'て': 'て', 'と': 'と',
+        'タ': 'た', 'チ': 'ち', 'ツ': 'つ', 'テ': 'て', 'ト': 'と',
+        'だ': 'た', 'ぢ': 'ち', 'づ': 'つ', 'で': 'て', 'ど': 'と',
+        'ダ': 'た', 'ヂ': 'ち', 'ヅ': 'つ', 'デ': 'て', 'ド': 'と',
+        'な': 'な', 'に': 'に', 'ぬ': 'ぬ', 'ね': 'ね', 'の': 'の',
+        'ナ': 'な', 'ニ': 'に', 'ヌ': 'ぬ', 'ネ': 'ね', 'ノ': 'の',
+        'は': 'は', 'ひ': 'ひ', 'ふ': 'ふ', 'へ': 'へ', 'ほ': 'ほ',
+        'ハ': 'は', 'ヒ': 'ひ', 'フ': 'ふ', 'ヘ': 'へ', 'ホ': 'ほ',
+        'ば': 'は', 'び': 'ひ', 'ぶ': 'ふ', 'べ': 'へ', 'ぼ': 'ほ',
+        'バ': 'は', 'ビ': 'ひ', 'ブ': 'ふ', 'ベ': 'へ', 'ボ': 'ほ',
+        'ま': 'ま', 'み': 'み', 'む': 'む', 'め': 'め', 'も': 'も',
+        'ぱ': 'は', 'ぴ': 'ひ', 'ぷ': 'ふ', 'ぺ': 'へ', 'ぽ': 'ほ',
+        'パ': 'は', 'ピ': 'ひ', 'プ': 'ふ', 'ペ': 'へ', 'ポ': 'ほ',
+        'マ': 'ま', 'ミ': 'み', 'ム': 'む', 'メ': 'め', 'モ': 'も',
+        'や': 'や', 'ゆ': 'ゆ', 'よ': 'よ', 'ヤ': 'や', 'ユ': 'ゆ', 'ヨ': 'よ',
+        'ゃ': 'や', 'ゅ': 'ゆ', 'ょ': 'よ', 'ャ': 'や', 'ュ': 'ゆ', 'ョ': 'よ',
+        'ら': 'ら', 'り': 'り', 'る': 'る', 'れ': 'れ', 'ろ': 'ろ',
+        'ラ': 'ら', 'リ': 'り', 'ル': 'る', 'レ': 'れ', 'ロ': 'ろ',
+        'わ': 'わ', 'を': 'を', 'ん': 'ん', 'ワ': 'わ', 'ヲ': 'を', 'ン': 'ん'
+        }
 
 
 def get_word_list_from_file(config):
@@ -505,7 +542,7 @@ class ExtIndexRack(idxr.IndexRack):
     処理概要
 
     1. self.__init__() 初期化. 設定からの読み込み.
-    2. self.append() ExtIndexUnitの取り込み. self.update()の準備.
+    2. self.append() ExtIndexUnitの取り込み. self.update_units()の準備.
     3. self.update_units() 各unitの更新、並び替えの準備.
     4. self.sort_units() 並び替え.
     5. self.generate_genindex_data() genindex用データの生成.
@@ -517,7 +554,7 @@ class ExtIndexRack(idxr.IndexRack):
     entryclass = ExtIndexEntry
 
     def __init__(self, builder, testmode=False):
-        """ExtIndexUnitの取り込み、整理、並べ替え. データの生成."""
+        """rstファイル外にある読み仮名情報の取り込み."""
 
         # 制御情報の保存
         self.testmode = testmode  # 0.24 未使用になった.
@@ -552,19 +589,19 @@ class ExtIndexRack(idxr.IndexRack):
 
     def append(self, unit):
         """
-        - 全unitを見て決める更新処理のための情報収集
+        - 更新処理のための全てのunitから情報を収集する.
         """
-        # 情報収集
+        # かな情報の収集
         self.put_in_kana_catalog(unit['main'], unit.get_terms())
         unit[UNIT_TERM].kana_text_on_genindex = self.config.kana_text_on_genindex
 
-        # 残りの処理
+        # 残りの情報収集とrackへの格納.
         super().append(unit)
 
     def put_in_kana_catalog(self, emphasis, terms):
         """KanaText用の処理"""
         for term in terms:
-            kana, ideo, ruby, spec = term.askana(), term.asideo(), term['ruby'], term['option']
+            kana, ideo, ruby, spec = term.askana(), term.astext(), term['ruby'], term['option']
             if kana and ideo in self._kana_catalog:
                 item = self._kana_catalog[ideo]
                 if emphasis < item[0]:
@@ -574,7 +611,7 @@ class ExtIndexRack(idxr.IndexRack):
                     # emphasisコードが同じなら、かな文字の長いほうが優先.
                     if len(kana) > len(item[1]):
                         self._kana_catalog[ideo] = (emphasis, kana, ruby, spec)
-                    # 検討）かな文字の長さも同じなら、、
+                    # かな文字の長さも同じなら、、
                     elif len(kana) == len(item[1]):
                         # 'specific'に限りオプションコードが多い方を採用する.
                         if ruby == 'specific' and ruby == item[2] and len(spec) > len(item[3]):
@@ -595,9 +632,9 @@ class ExtIndexRack(idxr.IndexRack):
         try:
             # パラメータに応じて変換テーブルを使い分ける.
             if 'small' == self.config.kana_text_indexer_mode:
-                return _first_char_small[text[:1]]
+                return _first_char.small[text[:1]]
             elif 'large' == self.config.kana_text_indexer_mode:
-                return _first_char_large[text[:1]]
+                return _first_char.large[text[:1]]
             else:
                 # 想定パラメータ以外なら基本的な処理
                 return text[:1].upper()
@@ -625,13 +662,14 @@ class ExtIndexRack(idxr.IndexRack):
             # kana_text_change_tripleの設定値を反映
             unit[UNIT_SBTM].change_triple = self.config.kana_text_change_triple
 
+        # 残りの更新処理
         super().update_units()
 
     def update_term_with_kana_catalog(self, term):
-        if term.asideo() in self._kana_catalog:
-            term['kana'] = self._kana_catalog[term.asideo()][1]
-            term['ruby'] = self._kana_catalog[term.asideo()][2]
-            term['option'] = self._kana_catalog[term.asideo()][3]
+        if term.astext() in self._kana_catalog:
+            term['kana'] = self._kana_catalog[term.astext()][1]
+            term['ruby'] = self._kana_catalog[term.astext()][2]
+            term['option'] = self._kana_catalog[term.astext()][3]
         else:
             pass
 
@@ -662,7 +700,7 @@ def depart_kana(self, node):
 
 class ExtHTML5Translator(html5.HTML5Translator):
 
-    def visit_term(self, node: Element) -> None:
+    def visit_term(self, node: nodes.Element) -> None:
         """
         目的の文字列をKanaTextクラスにするための対応.
         後は、add_nodeで割り当てたメソッドが行う.
@@ -692,7 +730,12 @@ class ExtHTML5Translator(html5.HTML5Translator):
 class ExtHTMLBuilder(idxr.HTMLBuilder):
     """索引ページの日本語対応"""
 
-    name = 'kana'
+    name = 'html'
+
+    #def build(self, docnames, summary = None, method = 'update'):
+    #    super().build(docnames, summary, method)
+    #    nodes.Text = KanaText
+    #エラーにならないだけで、HTMLTranslatorの代わりにはならない.
 
     def index_adapter(self) -> None:
         """索引の作成"""
@@ -700,6 +743,12 @@ class ExtHTMLBuilder(idxr.HTMLBuilder):
         return ExtIndexRack(self).create_index()
 
 
+class NormalHTMLBuilder(idxr.HTMLBuilder):
+    """日本語対応なし版"""
+
+    name = 'nokana'
+
+
 # ------------------------------------------------------------
 
 
@@ -730,8 +779,11 @@ def setup(app) -> Dict[str, Any]:
     # 索引の表示はExtHTMLBuilderで行う
 
     # HTML出力
-    app.add_builder(ExtHTMLBuilder)
-    app.set_translator('kana', ExtHTML5Translator)
+    app.add_builder(ExtHTMLBuilder, True)
+    app.set_translator('html', ExtHTML5Translator)
+
+    # HTML出力/sphindexer/"make idxr"
+    app.add_builder(NormalHTMLBuilder)
 
     # 設定の登録
     app.add_config_value('kana_text_separator', _dflt_separator, 'env')
@@ -742,7 +794,7 @@ def setup(app) -> Dict[str, Any]:
     app.add_config_value('kana_text_on_genindex', False, 'html')
     app.add_config_value('kana_text_change_triple', False, 'html')
 
-    # バージョンの最後は作成日（MMDDYY）
+    # バージョン情報（x.y.z.[.n[.YYYYMMDD]]）
     return {'version': __version__,
             'parallel_read_safe': True,
             'parallel_write_safe': True,
